==> spip_3.2.11.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_hu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=hu
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Effacer les statistiques', # MODIF

	// I
	'icone_evolution_visites' => 'Látógatások kialakulása<br />@visites@ látógatás', # MODIF
	'icone_repartition_actuelle' => 'Jelenlegi megosztás megjelenítése',
	'icone_repartition_visites' => 'Látógatások szétosztása',
	'icone_statistiques_visites' => 'Statisztikák',
	'info_affichier_visites_articles_plus_visites' => 'A látógatások megjelenítése a <b>kezdettől leglátógatottabb cikkekről :</b>',
	'info_comment_lire_tableau' => 'Hogyan kell értelmezni a táblát',
	'info_forum_statistiques' => 'Statisztikák a látógatásokról',
	'info_popularite_2' => 'Honlap népszerűsége :',
	'info_popularite_3' => 'Népszer?ség : @popularite@ ; látógatások : @visites@',
	'info_popularite_5' => 'népszerűség :',
	'info_visites' => 'látógatás :',
	'info_visites_plus_populaires' => 'Látógatások megjelenítése a <b>legnépszerűbb cikkekről</b> és a <b>legutóljára publikált cikkekről :</b>',
	'info_zoom' => 'nagyítás',
	'item_gerer_statistiques' => 'A statisztikák kezelése', # MODIF

	// O
	'onglet_origine_visites' => 'A látógatások származása',
	'onglet_repartition_debut' => 'kezdettől',
	'onglet_repartition_lang' => 'Nyelvek szerinti bontás',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'A népszerűség szerinti cikk rangja a márgóban jelenik meg ; a cikk népszerűsége (olyan becslés a leendő napi látógatásokról, ha az eddigi látógatási ütem megmarad) és a kezdet óta történt látógatások száma szerepel abban a buborékban, ami megjelenik, ha az egér lebeg a cím felett.',
	'texte_signification' => 'A sötét sávok a halmodozott belépéseket jelzik (alrovatok összege), a világos sávok pedig a látogatások számát minden rovatnak.',
	'titre_evolution_visite' => 'A látógatások kialakulása',
	'titre_liens_entrants' => 'Bejövő linkek',
	'titre_page_statistiques' => 'Rovatok szerinti statisztikák',
	'titre_page_statistiques_visites' => 'Statisztikák a latógatásokról'
);

==> spip_4.4.6+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_hu.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=hu
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_effacer_statistiques' => 'Effacer les statistiques', # MODIF

	// I
	'icone_evolution_visites' => 'Látógatások kialakulása<br />@visites@ látógatás', # MODIF
	'icone_repartition_actuelle' => 'Jelenlegi megosztás megjelenítése',
	'icone_repartition_visites' => 'Látógatások szétosztása',
	'icone_statistiques_visites' => 'Statisztikák',
	'info_affichier_visites_articles_plus_visites' => 'A látógatások megjelenítése a <b>kezdettől leglátógatottabb cikkekről :</b>',
	'info_comment_lire_tableau' => 'Hogyan kell értelmezni a táblát',
	'info_forum_statistiques' => 'Statisztikák a látógatásokról',
	'info_popularite_2' => 'Honlap népszerűsége :',
	'info_popularite_3' => 'Népszer?ség : @popularite@ ; látógatások : @visites@',
	'info_popularite_5' => 'népszerűség :',
	'info_visites' => 'látógatás :',
	'info_visites_plus_populaires' => 'Látógatások megjelenítése a <b>legnépszerűbb cikkekről</b> és a <b>legutóljára publikált cikkekről :</b>',
	'info_zoom' => 'nagyítás',
	'item_gerer_statistiques' => 'A statisztikák kezelése', # MODIF

	// O
	'onglet_origine_visites' => 'A látógatások származása',
	'onglet_repartition_debut' => 'kezdettől',
	'onglet_repartition_lang' => 'Nyelvek szerinti bontás',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_comment_lire_tableau' => 'A népszerűség szerinti cikk rangja a márgóban jelenik meg ; a cikk népszerűsége (olyan becslés a leendő napi látógatásokról, ha az eddigi látógatási ütem megmarad) és a kezdet óta történt látógatások száma szerepel abban a buborékban, ami megjelenik, ha az egér lebeg a cím felett.',
	'texte_signification' => 'A sötét sávok a halmodozott belépéseket jelzik (alrovatok összege), a világos sávok pedig a látogatások számát minden rovatnak.',
	'titre_evolution_visite' => 'A látógatások kialakulása',
	'titre_liens_entrants' => 'Bejövő linkek',
	'titre_page_statistiques' => 'Rovatok szerinti statisztikák',
	'titre_page_statistiques_visites' => 'Statisztikák a latógatásokról',
];
